@@ -17,11 +17,9 @@
 #
 # Unit tests for cinder::ceph class
 #
-
 require 'spec_helper'
 
 describe 'cinder::backup::ceph' do
-
   let :default_params do
     { :backup_ceph_conf         => '/etc/ceph/ceph.conf',
       :backup_ceph_user         => 'cinder',
@@ -35,13 +33,13 @@ describe 'cinder::backup::ceph' do
     {}
   end
 
-  shared_examples_for 'cinder backup with ceph' do
+  shared_examples 'cinder backup with ceph' do
     let :p do
       default_params.merge(params)
     end
 
     it 'configures cinder.conf' do
-      is_expected.to contain_cinder_config('DEFAULT/backup_driver').with_value('cinder.backup.drivers.ceph')
+      is_expected.to contain_cinder_config('DEFAULT/backup_driver').with_value('cinder.backup.drivers.ceph.CephBackupDriver')
       is_expected.to contain_cinder_config('DEFAULT/backup_ceph_conf').with_value(p[:backup_ceph_conf])
       is_expected.to contain_cinder_config('DEFAULT/backup_ceph_user').with_value(p[:backup_ceph_user])
       is_expected.to contain_cinder_config('DEFAULT/backup_ceph_chunk_size').with_value(p[:backup_ceph_chunk_size])
@@ -78,7 +76,7 @@ describe 'cinder::backup::ceph' do
         facts.merge(OSDefaults.get_facts({}))
       end
 
-      it_configures 'cinder backup with ceph'
+      it_behaves_like 'cinder backup with ceph'
     end
   end
 end
