@@ -3,8 +3,7 @@ require 'spec_helper'
 describe 'cinder' do
   let :req_params do
     {
-      :database_connection => 'mysql+pymysql://user:password@host/database',
-      :lock_path           => '/var/lock/cinder',
+      :lock_path => '/var/lock/cinder',
     }
   end
 
@@ -15,7 +14,6 @@ describe 'cinder' do
       end
 
       it { is_expected.to contain_class('cinder::params') }
-      it { is_expected.to contain_class('mysql::bindings::python') }
 
       it { is_expected.to contain_resources('cinder_config').with_purge(false) }
 
@@ -45,12 +43,13 @@ describe 'cinder' do
         is_expected.to contain_cinder_config('DEFAULT/default_availability_zone').with(:value => 'nova')
         is_expected.to contain_cinder_config('DEFAULT/allow_availability_zone_fallback').with(:value => '<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('DEFAULT/api_paste_config').with(:value => '/etc/cinder/api-paste.ini')
+        is_expected.to contain_cinder_config('oslo_concurrency/lock_path').with(:value => '/var/lock/cinder')
+        is_expected.to contain_cinder_config('DEFAULT/image_conversion_dir').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('DEFAULT/host').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('DEFAULT/enable_new_services').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_cinder_config('oslo_concurrency/lock_path').with(:value => '/var/lock/cinder')
-        is_expected.to contain_cinder_config('key_manager/backend').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_cinder_config('barbican/barbican_endpoint').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_cinder_config('barbican/auth_endpoint').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_cinder_config('DEFAULT/enable_force_upload').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_cinder_config('DEFAULT/cinder_internal_tenant_project_id').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_cinder_config('DEFAULT/cinder_internal_tenant_user_id').with_value('<SERVICE DEFAULT>')
 
         # backend_host should not be written to DEFAULT section
         is_expected.not_to contain_cinder_config('DEFAULT/backend_host')
@@ -167,7 +166,6 @@ describe 'cinder' do
         is_expected.to contain_cinder_config('oslo_messaging_amqp/ssl_cert_file').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('oslo_messaging_amqp/ssl_key_file').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('oslo_messaging_amqp/ssl_key_password').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_cinder_config('oslo_messaging_amqp/allow_insecure_clients').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('oslo_messaging_amqp/sasl_mechanisms').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('oslo_messaging_amqp/sasl_config_dir').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('oslo_messaging_amqp/sasl_config_name').with_value('<SERVICE DEFAULT>')
@@ -199,7 +197,6 @@ describe 'cinder' do
         is_expected.to contain_cinder_config('oslo_messaging_amqp/ssl_ca_file').with_value('/path/to/ca.cert')
         is_expected.to contain_cinder_config('oslo_messaging_amqp/ssl_cert_file').with_value('/path/to/certfile')
         is_expected.to contain_cinder_config('oslo_messaging_amqp/ssl_key_file').with_value('/path/to/key')
-        is_expected.to contain_cinder_config('oslo_messaging_amqp/allow_insecure_clients').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('oslo_messaging_amqp/sasl_mechanisms').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('oslo_messaging_amqp/sasl_config_dir').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('oslo_messaging_amqp/sasl_config_name').with_value('<SERVICE DEFAULT>')
@@ -208,28 +205,6 @@ describe 'cinder' do
       }
     end
 
-    context 'with postgresql' do
-      let :params do
-        {
-          :database_connection => 'postgresql://user:drowssap@host/database',
-        }
-      end
-
-      it { is_expected.not_to contain_class('mysql::python') }
-      it { is_expected.not_to contain_class('mysql::bindings') }
-      it { is_expected.not_to contain_class('mysql::bindings::python') }
-    end
-
-    context 'with APIs set for Mitaka (proposed)' do
-      let :params do
-        {
-          :enable_v3_api => true,
-        }
-      end
-
-      it { is_expected.to contain_cinder_config('DEFAULT/enable_v3_api').with_value(true) }
-    end
-
     context 'with image_conversion_dir' do
       let :params do
         req_params.merge({
@@ -292,6 +267,30 @@ describe 'cinder' do
         is_expected.to contain_cinder_config('barbican/auth_endpoint').with_value('https://localhost:5000/v3')
       end
     end
+
+    context 'with volume api paramaters' do
+      let :params do
+        req_params.merge!({
+          :enable_force_upload => true,
+        })
+      end
+      it 'should set volume api parameters' do
+        is_expected.to contain_cinder_config('DEFAULT/enable_force_upload').with_value(true)
+      end
+    end
+
+    context 'with internal tenant parameters' do
+      let :params do
+        req_params.merge!({
+          :cinder_internal_tenant_project_id => 'projectid',
+          :cinder_internal_tenant_user_id    => 'userid',
+        })
+      end
+      it 'should set internal tenant parameters' do
+        is_expected.to contain_cinder_config('DEFAULT/cinder_internal_tenant_project_id').with_value('projectid')
+        is_expected.to contain_cinder_config('DEFAULT/cinder_internal_tenant_user_id').with_value('userid')
+      end
+    end
   end
 
   on_supported_os({
