@@ -23,6 +23,7 @@ describe 'cinder::backend::pure' do
         is_expected.to contain_cinder_config('pure/use_multipath_for_image_xfer').with_value('true')
         is_expected.to contain_cinder_config('pure/use_chap_auth').with_value('false')
         is_expected.to contain_cinder_config('pure/image_volume_cache_enabled').with_value('true')
+        is_expected.to contain_cinder_config('pure/pure_host_personality').with_value('<SERVICE DEFAULT>')
       }
     end
 
@@ -42,6 +43,7 @@ describe 'cinder::backend::pure' do
         is_expected.to contain_cinder_config('pure/pure_api_token').with_value('abc123def456ghi789')
         is_expected.to contain_cinder_config('pure/use_multipath_for_image_xfer').with_value('true')
         is_expected.to contain_cinder_config('pure/use_chap_auth').with_value('true')
+        is_expected.to contain_cinder_config('pure/pure_host_personality').with_value('<SERVICE DEFAULT>')
       }
     end
 
@@ -56,6 +58,7 @@ describe 'cinder::backend::pure' do
         is_expected.to contain_cinder_config('pure/pure_api_token').with_value('abc123def456ghi789')
         is_expected.to contain_cinder_config('pure/use_multipath_for_image_xfer').with_value('true')
         is_expected.to contain_cinder_config('pure/use_chap_auth').with_value('false')
+        is_expected.to contain_cinder_config('pure/pure_host_personality').with_value('<SERVICE DEFAULT>')
       }
     end
 
@@ -79,7 +82,6 @@ describe 'cinder::backend::pure' do
         :properties => ['volume_backend_name=pure']
       )}
     end
-  end
 
     context 'pure volume driver with image_volume_cache_enabled disabled' do
       let :params do
@@ -91,6 +93,17 @@ describe 'cinder::backend::pure' do
       }
     end
 
+    context 'pure volume driver with pure_host_personality set' do
+      let :params do
+        req_params.merge({'pure_host_personality' => 'oracle-vm-server'})
+      end
+
+      it {
+        is_expected.to contain_cinder_config('pure/pure_host_personality').with_value('oracle-vm-server')
+      }
+    end
+  end
+
   on_supported_os({
     :supported_os => OSDefaults.get_supported_os
   }).each do |os,facts|
